@@ -14,15 +14,17 @@ class SocialSDK:
             setattr(self, k, v)
 
     def get_provider_class(self):
-        from .providers import FacebookProvider, GoogleProvider
+        from .providers import FacebookProvider, GoogleProvider, AppleProvider
         if self.social_type == 'facebook':
             return FacebookProvider
         elif self.social_type == 'google':
             return GoogleProvider
+        elif self.social_type == 'apple':
+            return AppleProvider
 
     def get_provider(self):
         provider_class = self.get_provider_class()
-        return provider_class(API_KEY=settings.API_KEY)
+        return provider_class()
 
     def login(self, token, **kwargs):
         provider = self.get_provider()
